/*
	Copyright (c) 2002 Jens Tinz
	All rights reserved.

	Redistribution and use in source and binary forms, with or without
	modification, are permitted provided that the following conditions
	are met:
	1. Redistributions of source code must retain the above copyright
	notice, this list of conditions and the following disclaimer.
	2. Redistributions in binary form must reproduce the above copyright
	notice, this list of conditions and the following disclaimer in the
	documentation and/or other materials provided with the distribution.
	3. The name of the author may not be used to endorse or promote products
	derived from this software without specific prior written permission.

	THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
	IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
	OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
	IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
	INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
	NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
	DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
	THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
	THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


// This file defines the layout of the pie menu in different contexts.
// You can easily customize it. Helpful functions are provided in pieFunctions.js

function PieItem(type, label, altlabel, src, func) {
	this.type= type;										// -1 dummy, 0= item, 1= submenu (dummys are placeholders that don't create dead areas)
	this.label= label;										// wow - it's the label
	this.altlabel= altlabel;									// label when alt is down
	this.src=  src;										// name of icon source without suffix
	this.func= func;										// associated function or submenu 
	this.img= null;										// image object of icon
}

var pie_itemsets= {
	
	navigation : [
		new PieItem(1, "Tab",				null,			"tab/menu",			"tab"),
		new PieItem(0, "Forward",			null,			"navigation/next",	"pie_f.next();"),
		new PieItem(1, "Page",			null,			"page/menu",		"page"),
		new PieItem(0, "Reload",			"Rl - skip cache",	"navigation/reload",	"pie_f.reload(pie_event.altKey);"),
		new PieItem(0, "context2",		null,			"tasks/menu",		""),
		new PieItem(0, "Back",			null,			"navigation/prev",	"pie_f.prev();"),
		new PieItem(1, "Window",			null,			"window/menu",		"window"),
		new PieItem(0, "Stop",			null,			"navigation/stop",	"pie_f.stop();"),
		//new PieItem(1, "Scroll",			null,			"scroll/menu",		"scroll"),
	],

	folder : [
		new PieItem(1, "Tab",				null,			"tab/menu",			"tab"),
		new PieItem(0, "Forward",			null,			"navigation/next",	"pie_f.next();"),
		new PieItem(1, "Page",			null,			"page/menu",		"page"),
		new PieItem(0, "Reload",			"Rl - skip cache",	"navigation/reload",	"pie_f.reload(pie_event.altKey);"),
		new PieItem(0, "context2",		null,			"tasks/menu",		""),
		new PieItem(0, "Back",			null,			"navigation/prev",	"pie_f.prev();"),
		new PieItem(1, "Window",			null,			"window/menu",		"window"),
		new PieItem(0, "Up",				null,			"navigation/up",		"pie_f.up(pie_doc.URL);"),
		//new PieItem(1, "Scroll",			null,			"scroll/menu",		"scroll"),
	],

	link : [
//		new PieItem(0, "Bookmark",		null,			"link/bookmark",		"pie_f.bookmark(pie_target.href, pie_target.innerHTML);"),
		new PieItem(1, "Tab",				null,			"tab/menu",			"tab"),
		new PieItem(0, "In New Tab",		null,			"link/intab",			"pie_f.openTab(pie_target.href);"),
		new PieItem(1, "Page",			null,			"page/menu",		"page"),
		new PieItem(0, "Save Target As&#133;",null,			"link/save",			"pie_f.saveAs(pie_target.href, pie_target.innerHTML);"),
		new PieItem(0, "context2",		null,			"tasks/menu",		""),
		new PieItem(0, "In New Win",		null,			"link/inwin",			"pie_f.openWindow(pie_target.href);"),
		new PieItem(1, "Window",			null,			"window/menu",		"window"),
		new PieItem(0, "Copy Location",	null,			"link/copyurl",		"pie_f.writeClipboard(pie_target.href);"),
		//new PieItem(1, "Scroll",			null,			"scroll/menu",		"scroll"),
	],

	edit : [
		new PieItem(1, "Tab",				null,			"tab/menu",			"tab"),
		new PieItem(0, "Copy",			null,			"edit/copy",			"pie_f.copy();"),
		new PieItem(1, "Page",			null,			"page/menu",		"page"),
		new PieItem(0, "Paste",			null,			"edit/paste",			"pie_f.paste();"),
		new PieItem(0, "context2",		null,			"tasks/menu",		""),
		new PieItem(0, "Cut",				null,			"edit/cut",			"pie_f.cut();"),
		new PieItem(1, "Window",			null,			"window/menu",		"window"),
		new PieItem(0, "Undo",			null,			"edit/undo",			"pie_f.undo();"),
		//new PieItem(1, "Scroll",			null,			"scroll/menu",		"scroll"),
	],
	
	image : [
		new PieItem(1, "Tab",				null,			"tab/menu",			"tab"),
		new PieItem(0, "Block Server",		null,			"image/block",		"pie_f.toggleImageBlock(pie_target.src);"),
		new PieItem(1, "Page",			null,			"page/menu",		"page"),
		new PieItem(0, "Save As&#133;",	null,			"image/save",		"pie_f.saveAs(pie_target.src, pie_doc.title);"),
		new PieItem(0, "context2",		null,			"tasks/menu",		""),
		new PieItem(0, "View",			null,			"image/view",		"pie_f.loadUrl(pie_target.src);"),
		new PieItem(1, "Window",			null,			"window/menu",		"window"),
		new PieItem(0, "Copy Location",	null,			"image/copyloc",		"pie_f.writeClipboard(pie_target.src);"),
		//new PieItem(1, "Scroll",			null,			"scroll/menu",		"scroll"),
	],
	
	navigation_sub : [
		new PieItem(0, "Forward",			null,			"navigation/next",	"pie_f.next();"),
		new PieItem(0, "Reload",			"Rl - skip cache",	"navigation/reload",	"pie_f.reload(pie_event.altKey);"),
		new PieItem(0, "Back",			null,			"navigation/prev",	"pie_f.prev();"),
		new PieItem(0, "Stop",			null,			"navigation/stop",	"pie_f.stop();"),
	],

	folder_sub : [
		new PieItem(0, "Forward",			null,			"navigation/next",	"pie_f.next();"),
		new PieItem(0, "Reload",			"Rl - skip cache",	"navigation/reload",	"pie_f.reload(pie_event.altKey);"),
		new PieItem(0, "Back",			null,			"navigation/prev",	"pie_f.prev();"),
		new PieItem(0, "Up",				null,			"navigation/up",		"pie_f.up(pie_doc.URL);"),
	],

	image_sub : [
		new PieItem(-1, "",				null,			"empty",				null),
		new PieItem(0, "Block Server",		null,			"image/block",		"pie_f.toggleImageBlock(pie_target2.src);"),
		new PieItem(-1, "",				null,			"empty",				null),
		new PieItem(0, "Save As&#133;",	null,			"image/save",		"pie_f.saveAs(pie_target2.src, pie_doc.title);"),
		new PieItem(1, "Navigation",		null,			"navigation/menu",	"navigation_sub"),
		new PieItem(0, "View",			null,			"image/view",		"pie_f.loadUrl(pie_target2.src);"),
		new PieItem(-1, "",				null,			"empty",				null),
		new PieItem(0, "Copy Location",	null,			"image/copyloc",		"pie_f.writeClipboard(pie_target2.src);"),
	],
	
	selection_sub : [
		new PieItem(0, "Open",			"* Open",		"selection/openurl",	"pie_f.loadUrl(pie_target2, pie_event.altKey);"),
		new PieItem(0, "Translate",		"* Translate",		"selection/translate",	"pie_f.translate(pie_target2, pie_event.altKey);"),
		new PieItem(0, "Search Web",		"* Search",		"selection/searchweb","pie_f.searchWeb(pie_target2, pie_event.altKey);"),
		new PieItem(0, "Copy",			null,			"selection/copy",	"pie_f.writeClipboard(pie_target2);"),
	],
	
	tab : [
		new PieItem(0, "Next Tab",		null,			"tab/next",			"pie_f.nextTab();"),
		new PieItem(0, "Close Tab",		null,			"tab/close",			"pie_f.closeTab();"),
		new PieItem(0, "Prev Tab",		null,			"tab/prev",			"pie_f.prevTab();"),
		new PieItem(0, "New Tab",		"Duplicate Tab",	"tab/new",			"pie_f.newTab(pie_event.altKey);"),
	],
	
	window : [
		new PieItem(0, "Fullscreen",		null,			"window/fullscreen",	"pie_f.toggleFullscreen();"),
		new PieItem(0, "Close Win",		null,			"window/close",		"pie_f.closeWindow();"),
		new PieItem(0, "Minimize",		null,			"window/minimize",	"pie_f.minimizeWindow();"),
		new PieItem(0, "New Win",		"Duplicate Win",	"window/new",		"pie_f.newWindow(pie_event.altKey);"),
	],
	
	page : [
		new PieItem(0, "Bookmark",		"Bookmark&#133;","page/bookmark",	"pie_f.bookmark(pie_doc.URL, pie_doc.title, pie_event.altKey);"),
		new PieItem(0, "Save As&#133;",	null,			"page/save",			"pie_f.savePage(pie_doc);"),
		new PieItem(0, "View Source",		null,			"page/source",		"pie_f.viewSource(pie_doc);"),
		new PieItem(0, "View Info",		null,			"page/info",			"pie_f.viewInfo();"),
	],
	
	frame : [
		new PieItem(-1, "",				null,			"empty",				null),
		new PieItem(0, "View",			null,			"frame/view",		"pie_f.loadUrl(pie_frame_doc.URL);"),
		new PieItem(1, "Page",			null,			"page/menu",		"page"),
		new PieItem(0, "Save As&#133;",	null,			"frame/save",		"pie_f.saveAs(pie_frame_doc.URL, pie_frame_doc.title);"),
		new PieItem(-1, "",				null,			"empty",				null),
		new PieItem(0, "Source",			null,			"frame/source",		"pie_f.viewSource(pie_frame_doc);"),
		new PieItem(-1, "",				null,			"empty",				null),
		new PieItem(0, "Info",				null,			"frame/info",			"pie_f.viewFrameInfo(pie_frame_doc);"),
	],

	scroll : [
		new PieItem(2, "Right scroll",		null,			"scroll/right",		"pie_f.scroll(pie_doc, 'R');"),
		new PieItem(2, "Down scroll",		null,			"scroll/down",		"pie_f.scroll(pie_doc, 'D');"),
		new PieItem(2, "Left scroll", 		null,			"scroll/left",			"pie_f.scroll(pie_doc, 'L');"),
		new PieItem(2, "Up scroll", 		null,			"scroll/up",			"pie_f.scroll(pie_doc, 'U');"),
	],

	tasks : [
		new PieItem(0, "Mail & News",		null,			"tasks/mail",			"pie_f.openMessenger();"),
		new PieItem(0, "IRC Chat",		null,			"tasks/chat",			"pie_f.openChat();"),
		new PieItem(0, "Address Book",	null,			"tasks/addresses",	"pie_f.openAddressbook();"),
		new PieItem(0, "Composer", 		null,			"tasks/composer",	"pie_f.openComposer();"),
	],
	
	context2 :		new PieItem(1, "context2",	null,	"tasks/menu",		"context2"),
	navigation_item :	new PieItem(1, "Navigation",	null,	"navigation/menu",	"navigation_sub"),
	folder_item :		new PieItem(1, "Navigation",	null,	"navigation/menu",	"folder_sub"),
	tasks_item :		new PieItem(1, "Tasks",		null,	"tasks/menu",		"tasks"),
	selection_item :	new PieItem(1, "Selection",	null,	"selection/menu",	"selection_sub"),
	image_item :		new PieItem(1, "Image",		null,	"image/menu",		"image_sub"),
	frame_item :		new PieItem(1, "Frame",		null,	"frame/menu",		"frame"),
	page_item :		new PieItem(1, "Page",		null,	"page/menu",		"page"),
}

